@@ -1,7 +1,7 @@
 from bs4 import BeautifulSoup
 from yarl import URL
 
-from ..base_functions import logger, ssl_context
+from ..base_functions import log, logger, ssl_context
 
 
 class RedGifsCrawler():
@@ -26,12 +26,12 @@ class RedGifsCrawler():
                         video_src = URL(link)
 
                 # Just get the first one if we didn't find the non-mobile
-                if video_src == None and len(video_metas) != 0:
+                if video_src is None and len(video_metas) != 0:
                     video_src = URL(video_metas[0].get("content"))
 
                 return video_src
 
         except Exception as e:
-            logger.debug("Error encountered while handling %s",
-                         str(url), exc_info=True)
+            logger.debug("Error encountered while handling %s", str(url), exc_info=True)
+            await log("Error scraping " + str(url))
             logger.debug(e)
